########################################################################
## This time I'm voting
## MARQUART/GOLDBERG/DE VREESE
## EUP

library(foreign)
library(MASS)  
library(lme4)
library(arm)
library(stargazer)
library(readstata13)
library(ggeffects)
library(sjstats)


########################################################################
########################## Data setup ##################################

data <- read.dta13("Marquart et al_data_EUP.dta",convert.factors=F)
names(data)

### define campaign variables as factors

data$camexp_analog_3cat <- factor(data$camexp_analog_3cat)
data$camexp_socialmedia_3cat <- factor(data$camexp_socialmedia_3cat)
data$camexp_event_3cat <- factor(data$camexp_event_3cat)
data$camexp_activeinfo_3cat <- factor(data$camexp_activeinfo_3)
data$camexp_material_3cat <- factor(data$camexp_material_3cat)
data$campaign_reclame_3cat <- factor(data$campaign_reclame_3cat)
data$campaign_poster_3cat <- factor(data$campaign_poster_3cat)
data$campaign_activecommonline_3cat <- factor(data$campaign_activecommonline_3cat)
data$campaign_convinceothers_3cat <- factor(data$campaign_convinceothers_3cat)
data$intperscomm_family_3cat <- factor(data$intperscomm_family_3cat)
data$intperscomm_colleagues_3cat <- factor(data$intperscomm_colleagues_3cat)
data$intperscomm_peopleonline_3cat <- factor(data$intperscomm_peopleonline_3cat)




########################################################################
####################### Multilevel models ##############################


##******************************************************
## EMPTY MULTILEVEL MODEL FOR ICC CALCULATION (p. 13/14)

M0 <- glmer(turnout ~ 1 + (1 | Q999), 
            data=data , family = binomial(link = "logit"))

performance::icc(M0)




##******************************************************
## TABLE 1

T1M1 <- glmer(turnout ~ 1 + 
              voteintention + polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
              leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
            + (1 | Q999), 
            data=data , family = binomial(link = "logit"))

T1M2 <- glmer(turnout ~ 1 +
               camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
               voteintention + polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
               leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED
             + (1 | Q999), 
             data=data , family = binomial(link = "logit"))

T1M3 <- glmer(turnout ~ 1 +
               camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
               voteintention + polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
               leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED
             + (1 | Q999), 
             data=data , family = binomial(link = "logit"))

T1M4 <- glmer(turnout ~ 1 + 
               intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
               voteintention + polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
               leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED
             + (1 | Q999), 
             data=data , family = binomial(link = "logit"))

T1M5 <- glmer(turnout ~ 1 +
              camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
              camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
              intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
              voteintention + polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
              leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED
            + (1 | Q999), 
            data=data , family = binomial(link = "logit"))

stargazer(T1M1, T1M2, T1M3, T1M4, T1M5, align=TRUE, star.cutoffs = c(0.05, 0.01, 0.001), type="text", style="ajps")


# (Changes in) predicted probabilities (final column in Table 1); differences calculated manually

ggpredict(T1M5, c("camexp_analog_3cat[0,1,2]"))
ggpredict(T1M5, c("campaign_poster_3cat[0,1,2]")) #only changes in predicted probabilities for category 2 put in Table

ggpredict(T1M5, c("camexp_event_3cat[0,1,2]"))
ggpredict(T1M5, c("camexp_activeinfo_3cat[0,1,2]"))
ggpredict(T1M5, c("camexp_material_3cat[0,1,2]"))
ggpredict(T1M5, c("campaign_activecommonline_3cat[0,1,2]"))
ggpredict(T1M5, c("campaign_convinceothers_3cat[0,1,2]"))

ggpredict(T1M5, c("intperscomm_family_3cat[0,1,2]")) #only changes in predicted probabilities for category 2 put in Table
ggpredict(T1M5, c("intperscomm_colleagues_3cat[0,1,2]")) #only changes in predicted probabilities for category 2 put in Table
ggpredict(T1M5, c("intperscomm_peopleonline_3cat[0,1,2]"))

ggpredict(T1M5, c("civicduty[0,3,6]")) # mentioned in the text as comparison
ggpredict(T1M5, c("polintEU[0,3,6]")) # mentioned in the text as comparison






##******************************************************
## TABLE 2

#subsetting of three types of respondents
abstainers <- subset(data, voteintention <1)
undecided <- subset(data, voteintention < 6 & voteintention >=1)
voters <- subset(data, voteintention >= 6) 


T2M1 <- glmer(turnout ~ 1 +
                   camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
                   camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
                   intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
                   polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                   leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
                 + (1 | Q999), 
                 data=abstainers , family = binomial(link = "logit"))

T2M2 <- glmer(turnout ~ 1 +
                    camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
                    camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
                    intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
                    polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                    leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
                  + (1 | Q999), 
                  data=undecided , family = binomial(link = "logit"))

T2M3 <- glmer(turnout ~ 1 +
                   camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
                   camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
                   intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
                   polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                   leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
                 + (1 | Q999), 
                 data=voters , family = binomial(link = "logit"))

stargazer(T2M1, T2M2, T2M3, align=TRUE, star.cutoffs = c(0.05, 0.01, 0.001), type="text", style="ajps")






##******************************************************
## TABLE A4

TA4M1 <- glmer(turnout ~ 1 +
                 camexp_analog + camexp_socialmedia + campaign_reclame + campaign_poster +
                 Q800E + activeinfo + camexp_material + activeonline + convince +
                 intperscomm_family + intperscomm_colleagues + intperscomm_peopleonline +
                 voteintention + polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                 leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
               + (1 | Q999), 
               data=data , family = binomial(link = "logit"))

stargazer(TA4M1, align=TRUE, star.cutoffs = c(0.05, 0.01, 0.001), type="text", style="ajps")








##******************************************************
## TABLE A5

#subsetting of three alternative types of respondents
likelyabst <- subset(data, voteintention <2) 
middle <- subset(data, voteintention < 5 & voteintention >=2)
likelyvot <- subset(data, voteintention >= 5)


TA5M1 <- glmer(turnout ~ 1 +
                   camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
                   camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
                   intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
                   polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                   leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
                 + (1 | Q999), 
                 data=likelyabst , family = binomial(link = "logit"))

TA5M2 <- glmer(turnout ~ 1 +
                    camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
                    camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
                    intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
                    polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                    leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
                  + (1 | Q999), 
                  data=middle , family = binomial(link = "logit"))

TA5M3 <- glmer(turnout ~ 1 +
                   camexp_analog_3cat + camexp_socialmedia_3cat + campaign_reclame_3cat + campaign_poster_3cat +
                   camexp_event_3cat + camexp_activeinfo_3cat + camexp_material_3cat + campaign_activecommonline_3cat + campaign_convinceothers_3cat +
                   intperscomm_family_3cat + intperscomm_colleagues_3cat + intperscomm_peopleonline_3cat +
                   polpart + polintEU + polefficacy + econeval + satisfactiongov + trustEP + civicduty + 
                   leftright + I(leftright*leftright) + age + I(age*age) + woman + ESISCED 
                 + (1 | Q999), 
                 data=likelyvot , family = binomial(link = "logit"))

stargazer(TA5M1, TA5M2, TA5M3, star.cutoffs = c(0.05, 0.01, 0.001), type="text", style="ajps")